package ir.myketBillingReactNative


import com.facebook.react.bridge.*
import ir.myket.billingclient.util.Purchase


class MyketBillingModule(private val reactContext: ReactApplicationContext) : ReactContextBaseJavaModule(reactContext) {

  override fun getName(): String = "MyketBillingModule"


  @ReactMethod
  fun connectPaymentWithListener(rsaPublicKey: String?, failureCallback: Callback, successCallback: Callback) {
    initializeCallBack(reactContext, rsaPublicKey, {failureCallback.invoke(it)},{successCallback.invoke(it)})
  }

  @ReactMethod
  fun disconnectPaymentWithListener(callback: Callback) {
    disposeCallBack { callback.invoke(it) }
  }

  @ReactMethod
  fun getPurchaseUpdateWithListener(querySkuDetails: Boolean?, moreSkus: ReadableArray?,failureCallback: Callback, successCallback: Callback) {
    queryInventoryCallBack(querySkuDetails, moreSkus?.toStringList(), { failureCallback.invoke(it) },{ successCallback.invoke(it)})
  }

  @ReactMethod
  fun launchProcessFlowWithListener(sku: String?, developerPayload: String?,failureCallback: Callback, successCallback: Callback) {
    startActivity(sku, developerPayload, failureCallback,successCallback)
  }

  @ReactMethod
  fun usePurchaseWithListener(purchase: Purchase,failureCallback: Callback, successCallback: Callback) {
    consumeAsyncCallBack(purchase,{failureCallback.invoke(it)},{successCallback.invoke(it)})
  }

  private fun startActivity(sku: String?, developerPayload: String?, failureCallback: Callback, successCallback: Callback) {
    if (isNotInitializedOrCurrentlyActive()) {
      failureCallback.invoke(IllegalStateException("Payment not connected!"))
      return
    }
    val activity = currentActivity
    if (activity == null) {
      failureCallback.invoke(IllegalStateException("Activity not found!"))
      return
    }
    PaymentActivity.start(activity, sku, developerPayload,failureCallback,successCallback)
  }


}
